@@ -26,11 +26,11 @@ class space_wrap:
 
         # iterate over the rows of the dataframe
         for i, row in df.iterrows():
-            doc = nlp(row['text'])
+            doc = nlp(row[column])
             # iterate over the tokens
             for token in doc:
                 # add a new row to the list with the word, the original sentence, the start index, the end index and the entity
-                rows.append([token.text, row['text'], token.i, token.i+1, token.ent_type_])
+                rows.append([token.text, row[column], token.i, token.i+1, token.ent_type_])
 
         # create a new dataframe with the desired columns
         df_new = pd.DataFrame(rows, columns=['token', 'text', 'start','end','entity'])
